@@ -3,6 +3,7 @@
 from contextlib import contextmanager
 from functools import wraps, total_ordering
 import logging
+import os
 import re
 import threading
 
@@ -11,7 +12,8 @@ from six import string_types
 
 from fiona._env import (
     GDALEnv, calc_gdal_version_num, get_gdal_version_num, get_gdal_config,
-    set_gdal_config, get_gdal_release_name)
+    set_gdal_config, get_gdal_release_name, GDALDataFinder, PROJDataFinder,
+    set_proj_data_search_path)
 from fiona.compat import getargspec
 from fiona.errors import EnvError, GDALVersionError
 from fiona.session import Session, DummySession
@@ -581,3 +583,34 @@ def require_gdal_version(version, param=None, values=None, is_max_version=False,
         return wrapper
 
     return decorator
+
+
+# Patch the environment if needed, such as in the installed wheel case.
+
+if "GDAL_DATA" not in os.environ:
+
+    # See https://github.com/mapbox/rasterio/issues/1631.
+    if GDALDataFinder().find_file("header.dxf"):
+        log.debug("GDAL data files are available at built-in paths")
+
+    else:
+        path = GDALDataFinder().search()
+
+        if path:
+            os.environ['GDAL_DATA'] = path
+            log.debug("GDAL_DATA not found in environment, set to %r.", path)
+
+if "PROJ_LIB" in os.environ:
+    path = os.environ["PROJ_LIB"]
+    set_proj_data_search_path(path)
+
+# See https://github.com/mapbox/rasterio/issues/1631.
+elif PROJDataFinder().has_data():
+    log.debug("PROJ data files are available at built-in paths")
+
+else:
+    path = PROJDataFinder().search()
+
+    if path:
+        log.debug("PROJ data not found in environment, setting to %r.", path)
+        set_proj_data_search_path(path)
