@@ -70,6 +70,16 @@ def path_curves_line_csv(data_dir):
     return os.path.join(data_dir, 'curves_line.csv')
 
 
+@pytest.fixture(scope='session')
+def path_test_tin_shp(data_dir):
+    """Path to ```test_tin.shp``"""
+    return os.path.join(data_dir, 'test_tin.shp')
+
+@pytest.fixture(scope='session')
+def path_test_tin_csv(data_dir):
+    """Path to ```test_tin.csv``"""
+    return os.path.join(data_dir, 'test_tin.csv')
+
 @pytest.fixture(scope='session')
 def path_coutwildrnp_shp(data_dir):
     """Path to ```coutwildrnp.shp``"""
@@ -250,6 +260,18 @@ requires_gdal22 = pytest.mark.skipif(
     not gdal_version.at_least('2.2'),
     reason="Requires GDAL 2.2.x")
 
+requires_gdal24 = pytest.mark.skipif(
+    not gdal_version.at_least('2.4'),
+    reason="Requires GDAL 2.4.x")
+
+requires_gdal_lt_3 = pytest.mark.skipif(
+    not gdal_version.major < 3,
+    reason="Requires GDAL < 3")
+
+requires_gdal3 = pytest.mark.skipif(
+    not gdal_version.major >= 3,
+    reason="Requires GDAL 3.x")
+
 
 @pytest.fixture(scope="class")
 def unittest_data_dir(data_dir, request):
